# -*- ruby -*-
# sake variant sake1

# The build tool driving this makefile is a custom one. To get it, you may use the command
#
#   svn co https://pdis-miso.svn.sourceforge.net/svnroot/pdis-miso/trunk/sake

require 'sake1/component'

$comp = Sake::Component.new(:target_type => :application,
                            :basename => 'smsexporter',
                            :name => "SMS Exporter",
                            :vendor => "Tero Hasu",
                            :version => [1, 9],
                            :uid_v8 => 0x10206ba3, # allocated from Symbian
                            :caps => %w{ReadUserData WriteUserData})

def try_load file
  begin
    load file
  rescue LoadError; end
end

if $sake_op[:kits]
  $kits = Sake::DevKits::get_exact_set($sake_op[:kits].strip.split(/,/))
else
  $kits = Sake::DevKits::get_all
end

$builds = $kits.map do |kit|
  Sake::CompBuild.new :component => $comp, :devkit => kit
end

# For any v9 builds, configure certificate info for signing. See
# Sake::CompBuild for the attributes to set.
try_load('local/signing.rb')

$builds.delete_if do |build|
  build.sign and !build.cert_file
end

if $sake_op[:builds]
  blist = $sake_op[:builds]
  $builds.delete_if do |build|
    !blist.include?(build.handle)
  end
end

class HexNum
  def initialize num
    @num = num
  end

  def to_s
    "0x%08x" % @num
  end
end

for build in $builds
  # To define __UID__ for header files.
  build.trait_map[:uid] = HexNum.new(build.uid3.number)
end

for build in $builds
  map = build.trait_map
  if $sake_op[:logging] and map[:has_flogger]
    map[:do_logging] = :define
  end

  build.plats = (build.v9? ? "gcce" : "armi")
end

task :default => [:bin, :sis]

require 'sake1/tasks'

Sake::Tasks::def_list_devices_tasks(:builds => $builds)

Sake::Tasks::def_makefile_tasks(:builds => $builds)

Sake::Tasks::def_binary_tasks(:builds => $builds)

Sake::Tasks::def_sis_tasks(:builds => $builds)

Sake::Tasks::def_clean_tasks(:builds => $builds)

task :all => [:makefiles, :bin, :sis]

def get_src_file_list
  list =
    %w{sakefile.rb} +
    # Symbian style build files
    Dir["build/**/bld.inf"] +
    Dir["build/**/*.mmp"] +
    Dir["build/**/*.pkg"] +
    Dir["src/icons.mk"] +
    # source files
    Dir["build/**/sconfig.hrh"] +
    Dir["src/*.in"] +
    Dir["src/*.xml"] +
    Dir["src/**/*.cpp"] + Dir["src/**/*.h"] +
    Dir["src/**/*.hrh"] + Dir["src/**/*.rss"] +
    Dir["src/**/*.loc"] +
    Dir["src/**/*.bmp"] + Dir["src/**/*.svg"]
  return list.sort
end

task :src_list do
  for file in get_src_file_list
    puts file
  end
end

Sake::Tasks::def_dist_tasks :builds => $builds, :files => get_src_file_list

# Configure any rules related to releasing and uploading and such
# things. Probably at least involves copying or uploading the
# distribution files somewhere.
try_load('local/releasing.rb')

Sake::Tasks::force_uncurrent_on_op_change
